'use strict';
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HandleExceptions = void 0;
const youch_1 = __importDefault(require("youch"));
// @ts-expect-error
const youch_terminal_1 = __importDefault(require("youch-terminal"));
const goodies_1 = require("@supercharge/goodies");
class HandleExceptions {
    /**
     * Bootstrap the application. This will listen for exceptions
     * crashing your Node.js process. The listeners will print
     * a message to the terminal before exiting the process.
     */
    async bootstrap() {
        process
            // eslint-disable-next-line @typescript-eslint/no-misused-promises
            .on('uncaughtException', async (error) => {
            await this.handle(error);
        })
            // eslint-disable-next-line @typescript-eslint/no-misused-promises
            .on('unhandledRejection', async (error) => {
            await this.handle(error);
        });
    }
    /**
     * Pretty-print the given `error` to the terminal.
     *
     * @param {Error} error
     */
    async handle(error) {
        await (0, goodies_1.tap)(new youch_1.default(error, {}).toJSON(), output => {
            console.log((0, youch_terminal_1.default)(output));
            process.exit(1);
        });
    }
}
exports.HandleExceptions = HandleExceptions;
