import { DotenvConfigOptions } from 'dotenv';
import { Application, Bootstrapper } from '@supercharge/contracts';
export declare class LoadEnvironmentVariables implements Bootstrapper {
    /**
     * The application instance.
     */
    private readonly app;
    /**
     * Create a new instance.
     *
     * @param app Application
     */
    constructor(app: Application);
    /**
     * Boot application services.
     */
    bootstrap(): Promise<void>;
    /**
     * Load the contents of the configured environment file. Throws an error
     * in case the environment file does not exist, an error will be thrown.
     *
     * @throws
     */
    loadEnvironment(): Promise<void>;
    /**
     * Load the app’s configured environment file.
     */
    loadDefaultEnvironmentFile(): Promise<void>;
    /**
     * Load the given environment `file` content into `process.env`.
     */
    loadEnvironmentFile(path: string, options: DotenvConfigOptions): Promise<void>;
    /**
     * Check if an environment file exists for the configured `NODE_ENV`. For example,
     * if `NODE_ENV=testing`, check whether a `.env.testing` file exists and loadd it.
     */
    loadSpecificEnvironmentFile(): Promise<void>;
}
