import { Command, Application as Craft } from '@supercharge/console';
import { Application, BootstrapperCtor, ConsoleKernel as ConsoleKernelContract } from '@supercharge/contracts';
export declare class ConsoleKernel implements ConsoleKernelContract {
    private readonly meta;
    /**
     * Create a new console kernel instance.
     *
     * @param {Application} app
     */
    constructor(app: Application);
    /**
     * Creates a new console kernel instance for the given `app`.
     *
     * @param {Application} app
     */
    static for(app: Application): ConsoleKernel;
    /**
     * Returns the application instance.
     *
     * @returns {Application}
     */
    app(): Application;
    /**
     * Returns the list of application bootstrappers.
     */
    protected bootstrappers(): BootstrapperCtor[];
    /**
     * Handle an incoming console command for the given `input`.
     *
     * @param {Array} input - command line arguments (process.argv)
     *
     * @returns {Promise}
     */
    run(input?: string[]): Promise<any>;
    /**
     * Prepare the console application by running the configured bootstrappers.
     * This method doesn’t register configured commands in the application.
     * It prepares the console application which is useful for testing.
     */
    prepare(): Promise<this>;
    /**
     * Bootstrap the console application for Craft commands.
     */
    bootstrap(): Promise<void>;
    /**
     * Register the console commands to the application.
     */
    commands(): Promise<void>;
    /**
     * Register all of the commands in the given `directories`.
     *
     * @param {Array} paths
     */
    loadFrom(...paths: string[]): Promise<void>;
    /**
     * Requires the given file from disk.
     *
     * @param {String} commandFile
     *
     * @returns {Command}
     */
    resolve(commandFile: string): Promise<Command>;
    /**
     * Returns a Craft console application instance.
     *
     * @returns {Craft}
     */
    craft(): Craft;
}
